@@ -1,6 +1,7 @@
 pub mod wordbank;
-pub mod user_guess;
+pub mod user_input;
 pub mod display;
-pub mod guess_processor;
 pub mod constants;
-pub mod err;
\ No newline at end of file
+pub mod err;
+pub mod highscore;
+pub mod utils;
\ No newline at end of file
